@@ -47,7 +47,7 @@ pub struct ShellSpawnInfo<'s, 'n> {
 
 pub fn spawn_shell(settings: &Settings, config: KubeConfig, session: &Session) -> Result<()> {
     let kind = match &settings.shell {
-        Some(shell) => ShellKind::from_str(&shell).ok_or_else(|| anyhow!("Invalid shell setting: {}", shell))?,
+        Some(shell) => ShellKind::from_str(shell).ok_or_else(|| anyhow!("Invalid shell setting: {}", shell))?,
         None => detect()?,
     };
 
